createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ChartEntry createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ChartEntry createEmptyInstance() => create();